@@ -42,15 +42,12 @@ import org.apache.tomcat.util.res.StringManager;
 import org.apache.tomcat.util.security.Escape;
 
 /**
- * <p>
- * Implementation of a Valve that outputs HTML error pages.
- * </p>
- * <p>
- * This Valve should be attached at the Host level, although it will work if attached to a Context.
- * </p>
- * <p>
- * HTML code from the Cocoon 2 project.
- * </p>
+ * <p>Implementation of a Valve that outputs HTML error pages.</p>
+ *
+ * <p>This Valve should be attached at the Host level, although it will work
+ * if attached to a Context.</p>
+ *
+ * <p>HTML code from the Cocoon 2 project.</p>
  *
  * @author Remy Maucherat
  * @author Craig R. McClanahan
@@ -67,7 +64,7 @@ public class ErrorReportValve extends ValveBase {
     private final ErrorPageSupport errorPageSupport = new ErrorPageSupport();
 
 
-    // ------------------------------------------------------ Constructor
+    //------------------------------------------------------ Constructor
 
     public ErrorReportValve() {
         super(true);
@@ -77,13 +74,15 @@ public class ErrorReportValve extends ValveBase {
     // --------------------------------------------------------- Public Methods
 
     /**
-     * Invoke the next Valve in the sequence. When the invoke returns, check the response state. If the status code is
-     * greater than or equal to 400 or an uncaught exception was thrown then the error handling will be triggered.
+     * Invoke the next Valve in the sequence. When the invoke returns, check
+     * the response state. If the status code is greater than or equal to 400
+     * or an uncaught exception was thrown then the error handling will be
+     * triggered.
      *
-     * @param request  The servlet request to be processed
+     * @param request The servlet request to be processed
      * @param response The servlet response to be created
      *
-     * @exception IOException      if an input/output error occurs
+     * @exception IOException if an input/output error occurs
      * @exception ServletException if a servlet error occurs
      */
     @Override
@@ -142,6 +141,23 @@ public class ErrorReportValve extends ValveBase {
         response.setSuspended(false);
 
         try {
+            int statusCode = response.getStatus();
+
+            // Do nothing on a 1xx, 2xx and 3xx status
+            // Do nothing if anything has been written already
+            // Do nothing if the response hasn't been explicitly marked as in error
+            //    and that error has not been reported.
+            if (statusCode < 400 || response.getContentWritten() > 0 || !response.setErrorReported()) {
+                return;
+            }
+
+            // If an error has occurred that prevents further I/O, don't waste time
+            // producing an error report that will never be read
+            AtomicBoolean result = new AtomicBoolean(false);
+            response.getCoyoteResponse().action(ActionCode.IS_IO_ALLOWED, result);
+            if (!result.get()) {
+                return;
+            }
             report(request, response, throwable);
         } catch (Throwable tt) {
             ExceptionUtils.handleThrowable(tt);
@@ -153,14 +169,15 @@ public class ErrorReportValve extends ValveBase {
 
 
     /**
-     * Return the error page associated with the specified status and exception.
+     * Prints out an error report.
      *
-     * @param statusCode the status code
-     * @param throwable  the exception
-     *
-     * @return the associated error page
+     * @param request The request being processed
+     * @param response The response being generated
+     * @param throwable The exception that occurred (which possibly wraps
+     *  a root cause exception
      */
-    protected ErrorPage findErrorPage(int statusCode, Throwable throwable) {
+    protected void report(Request request, Response response, Throwable throwable) {
+        int statusCode = response.getStatus();
         ErrorPage errorPage = null;
         if (throwable != null) {
             errorPage = errorPageSupport.find(throwable);
@@ -172,39 +189,8 @@ public class ErrorReportValve extends ValveBase {
             // Default error page
             errorPage = errorPageSupport.find(0);
         }
-        return errorPage;
-    }
 
 
-    /**
-     * Prints out an error report.
-     *
-     * @param request   The request being processed
-     * @param response  The response being generated
-     * @param throwable The exception that occurred (which possibly wraps a root cause exception
-     */
-    protected void report(Request request, Response response, Throwable throwable) {
-
-        int statusCode = response.getStatus();
-
-        // Do nothing on a 1xx, 2xx and 3xx status
-        // Do nothing if anything has been written already
-        // Do nothing if the response hasn't been explicitly marked as in error
-        // and that error has not been reported.
-        if (statusCode < 400 || response.getContentWritten() > 0 || !response.setErrorReported()) {
-            return;
-        }
-
-        // If an error has occurred that prevents further I/O, don't waste time
-        // producing an error report that will never be read
-        AtomicBoolean result = new AtomicBoolean(false);
-        response.getCoyoteResponse().action(ActionCode.IS_IO_ALLOWED, result);
-        if (!result.get()) {
-            return;
-        }
-
-        ErrorPage errorPage = findErrorPage(statusCode, throwable);
-
         if (errorPage != null) {
             if (sendErrorPage(errorPage.getLocation(), response)) {
                 // If the page was sent successfully, don't write the standard
@@ -232,7 +218,8 @@ public class ErrorReportValve extends ValveBase {
         // no error message provided
         String reason = null;
         String description = null;
-        StringManager smClient = StringManager.getManager(Constants.Package, request.getLocales());
+        StringManager smClient = StringManager.getManager(
+                Constants.Package, request.getLocales());
         response.setLocale(smClient.getLocale());
         try {
             reason = smClient.getString("http." + statusCode + ".reason");
@@ -255,15 +242,16 @@ public class ErrorReportValve extends ValveBase {
         sb.append(smClient.getLocale().getLanguage()).append("\">");
         sb.append("<head>");
         sb.append("<title>");
-        sb.append(smClient.getString("errorReportValve.statusHeader", String.valueOf(statusCode), reason));
+        sb.append(smClient.getString("errorReportValve.statusHeader",
+                String.valueOf(statusCode), reason));
         sb.append("</title>");
         sb.append("<style type=\"text/css\">");
         sb.append(TomcatCSS.TOMCAT_CSS);
         sb.append("</style>");
         sb.append("</head><body>");
         sb.append("<h1>");
-        sb.append(smClient.getString("errorReportValve.statusHeader", String.valueOf(statusCode), reason))
-                .append("</h1>");
+        sb.append(smClient.getString("errorReportValve.statusHeader",
+                String.valueOf(statusCode), reason)).append("</h1>");
         if (isShowReport()) {
             sb.append("<hr class=\"line\" />");
             sb.append("<p><b>");
@@ -329,7 +317,7 @@ public class ErrorReportValve extends ValveBase {
             } catch (Throwable t) {
                 ExceptionUtils.handleThrowable(t);
                 if (container.getLogger().isDebugEnabled()) {
-                    container.getLogger().debug(sm.getString("errorReportValve.contentTypeFail"), t);
+                    container.getLogger().debug("Failure to set the content-type of response", t);
                 }
             }
             Writer writer = response.getReporter();
@@ -347,10 +335,9 @@ public class ErrorReportValve extends ValveBase {
 
 
     /**
-     * Print out a partial servlet stack trace (truncating at the last occurrence of javax.servlet.).
-     *
+     * Print out a partial servlet stack trace (truncating at the last
+     * occurrence of javax.servlet.).
      * @param t The stack trace to process
-     *
      * @return the stack trace relative to the application layer
      */
     protected String getPartialServletStackTrace(Throwable t) {
@@ -359,14 +346,16 @@ public class ErrorReportValve extends ValveBase {
         StackTraceElement[] elements = t.getStackTrace();
         int pos = elements.length;
         for (int i = elements.length - 1; i >= 0; i--) {
-            if ((elements[i].getClassName().startsWith("org.apache.catalina.core.ApplicationFilterChain")) &&
-                    (elements[i].getMethodName().equals("internalDoFilter"))) {
+            if ((elements[i].getClassName().startsWith
+                 ("org.apache.catalina.core.ApplicationFilterChain"))
+                && (elements[i].getMethodName().equals("internalDoFilter"))) {
                 pos = i;
                 break;
             }
         }
         for (int i = 0; i < pos; i++) {
-            if (!(elements[i].getClassName().startsWith("org.apache.catalina.core."))) {
+            if (!(elements[i].getClassName().startsWith
+                  ("org.apache.catalina.core."))) {
                 trace.append('\t').append(elements[i].toString()).append(System.lineSeparator());
             }
         }
@@ -380,7 +369,8 @@ public class ErrorReportValve extends ValveBase {
             file = new File(getContainer().getCatalinaBase(), location);
         }
         if (!file.isFile() || !file.canRead()) {
-            getContainer().getLogger().warn(sm.getString("errorReportValve.errorPageNotFound", location));
+            getContainer().getLogger().warn(
+                    sm.getString("errorReportValve.errorPageNotFound", location));
             return false;
         }
 
@@ -389,12 +379,12 @@ public class ErrorReportValve extends ValveBase {
         response.setContentType("text/html");
         response.setCharacterEncoding("UTF-8");
 
-        try {
-            OutputStream os = response.getOutputStream();
-            InputStream is = new FileInputStream(file);
+        try (OutputStream os = response.getOutputStream();
+                InputStream is = new FileInputStream(file);){
             IOTools.flow(is, os);
         } catch (IOException e) {
-            getContainer().getLogger().warn(sm.getString("errorReportValve.errorPageIOException", location), e);
+            getContainer().getLogger().warn(
+                    sm.getString("errorReportValve.errorPageIOException", location), e);
             return false;
         }
 
